@@ -10,11 +10,12 @@ require 'uri'
 
 # other files we need
 require 'sinatra/show_exceptions'
+require 'sinatra/ext'
 require 'sinatra/version'
 
 module Sinatra
   # The request object. See Rack::Request for more info:
-  # http://rack.rubyforge.org/doc/classes/Rack/Request.html
+  # http://rubydoc.info/github/rack/rack/master/Rack/Request
   class Request < Rack::Request
     HEADER_PARAM = /\s*[\w.]+=(?:[\w.]+|"(?:[^"\\]|\\.)*")?\s*/
     HEADER_VALUE_WITH_PARAMS = /(?:(?:\w+|\*)\/(?:\w+(?:\.|\-|\+)?|\*)*)\s*(?:;#{HEADER_PARAM})*/
@@ -72,6 +73,7 @@ module Sinatra
 
     class AcceptEntry
       attr_accessor :params
+      attr_reader :entry
 
       def initialize(entry)
         params = entry.scan(HEADER_PARAM).map! do |s|
@@ -115,8 +117,8 @@ module Sinatra
 
   # The response object. See Rack::Response and Rack::Response::Helpers for
   # more info:
-  # http://rack.rubyforge.org/doc/classes/Rack/Response.html
-  # http://rack.rubyforge.org/doc/classes/Rack/Response/Helpers.html
+  # http://rubydoc.info/github/rack/rack/master/Rack/Response
+  # http://rubydoc.info/github/rack/rack/master/Rack/Response/Helpers
   class Response < Rack::Response
     DROP_BODY_RESPONSES = [204, 205, 304]
     def initialize(*)
@@ -390,7 +392,7 @@ module Sinatra
       end
 
       def close
-        return if @closed
+        return if closed?
         @closed = true
         @scheduler.schedule { @callbacks.each { |c| c.call }}
       end
@@ -413,7 +415,7 @@ module Sinatra
       end
 
       def callback(&block)
-        return yield if @closed
+        return yield if closed?
         @callbacks << block
       end
 
@@ -768,9 +770,16 @@ module Sinatra
     # named name.ext, where ext is registered on engine.
     def find_template(views, name, engine)
       yield ::File.join(views, "#{name}.#{@preferred_extension}")
-      Tilt.mappings.each do |ext, engines|
-        next unless ext != @preferred_extension and engines.include? engine
-        yield ::File.join(views, "#{name}.#{ext}")
+
+      if Tilt.respond_to?(:mappings)
+        Tilt.mappings.each do |ext, engines|
+          next unless ext != @preferred_extension and engines.include? engine
+          yield ::File.join(views, "#{name}.#{ext}")
+        end
+      else
+        Tilt.default_mapping.extensions_for(engine).each do |ext|
+          yield ::File.join(views, "#{name}.#{ext}") unless ext == @preferred_extension
+        end
       end
     end
 
@@ -1026,7 +1035,7 @@ module Sinatra
     # a matching file is found, returns nil otherwise.
     def static!(options = {})
       return if (public_dir = settings.public_folder).nil?
-      path = File.expand_path("#{public_dir}#{unescape(request.path_info)}" )
+      path = File.expand_path("#{public_dir}#{URI_INSTANCE.unescape(request.path_info)}" )
       return unless File.file?(path)
 
       env['sinatra.static_file'] = path
@@ -1132,7 +1141,7 @@ module Sinatra
     end
 
     def dump_errors!(boom)
-      msg = ["#{boom.class} - #{boom.message}:", *boom.backtrace].join("\n\t")
+      msg = ["#{Time.now.strftime("%Y-%m-%d %H:%M:%S")} - #{boom.class} - #{boom.message}:", *boom.backtrace].join("\n\t")
       @env['rack.errors'].puts(msg)
     end
 
@@ -1496,8 +1505,7 @@ module Sinatra
       def start_server(handler, server_settings, handler_name)
         handler.run(self, server_settings) do |server|
           unless handler_name =~ /cgi/i
-            $stderr.puts "== Sinatra/#{Sinatra::VERSION} has taken the stage " +
-            "on #{port} for #{environment} with backup from #{handler_name}"
+            $stderr.puts "== Sinatra (v#{Sinatra::VERSION}) has taken the stage on #{port} for #{environment} with backup from #{handler_name}"
           end
 
           setup_traps
@@ -1610,25 +1618,21 @@ module Sinatra
         if path.respond_to? :to_str
           keys = []
 
-          # We append a / at the end if there was one.
-          # Reason: Splitting does not split off an empty
-          # string at the end if the split separator
-          # is at the end.
-          #
-          postfix = '/' if path =~ /\/\z/
-
           # Split the path into pieces in between forward slashes.
+          # A negative number is given as the second argument of path.split
+          # because with this number, the method does not ignore / at the end
+          # and appends an empty string at the end of the return value.
           #
-          segments = path.split('/').map! do |segment|
+          segments = path.split('/', -1).map! do |segment|
             ignore = []
 
             # Special character handling.
             #
-            pattern = segment.to_str.gsub(/[^\?\%\\\/\:\*\w]/) do |c|
+            pattern = segment.to_str.gsub(/[^\?\%\\\/\:\*\w]|:(?!\w)/) do |c|
               ignore << escaped(c).join if c.match(/[\.@]/)
               patt = encoded(c)
               patt.gsub(/%[\da-fA-F]{2}/) do |match|
-                match.split(//).map! {|char| char =~ /[A-Z]/ ? "[#{char}#{char.tr('A-Z', 'a-z')}]" : char}.join
+                match.split(//).map! { |char| char == char.downcase ? char : "[#{char}#{char.downcase}]" }.join
               end
             end
 
@@ -1651,16 +1655,12 @@ module Sinatra
 
           # Special case handling.
           #
-          if segment = segments.pop
-            if segment.match(/\[\^\\\./)
-              parts = segment.rpartition(/\[\^\\\./)
-              parts[1] = '[^'
-              segments << parts.join
-            else
-              segments << segment
-            end
+          if last_segment = segments[-1] and last_segment.match(/\[\^\\\./)
+            parts = last_segment.rpartition(/\[\^\\\./)
+            parts[1] = '[^'
+            segments[-1] = parts.join
           end
-          [/\A#{segments.join('/')}#{postfix}\z/, keys]
+          [/\A#{segments.join('/')}\z/, keys]
         elsif path.respond_to?(:keys) && path.respond_to?(:match)
           [path, path.keys]
         elsif path.respond_to?(:names) && path.respond_to?(:match)
@@ -1691,10 +1691,7 @@ module Sinatra
         end
         unsafe_patterns = unsafe_ignore.map! do |unsafe|
           chars = unsafe.split(//).map! do |char|
-            if char =~ /[A-Z]/
-              char <<= char.tr('A-Z', 'a-z')
-            end
-            char
+            char == char.downcase ? char : char + char.downcase
           end
 
           "|(?:%[^#{chars[0]}].|%[#{chars[0]}][^#{chars[1]}])"
@@ -1769,6 +1766,8 @@ module Sinatra
           begin
             return Rack::Handler.get(server_name.to_s)
           rescue LoadError, NameError
+          rescue ArgumentError
+            Sinatra::Ext.get_handler(server_name.to_s)
           end
         end
         fail "Server handler (#{servers.join(',')}) not found."
@@ -1899,7 +1898,7 @@ module Sinatra
 
     configure :development do
       get '/__sinatra__/:image.png' do
-        filename = File.dirname(__FILE__) + "/images/#{params[:image]}.png"
+        filename = File.dirname(__FILE__) + "/images/#{params[:image].to_i}.png"
         content_type :png
         send_file filename
       end
@@ -1941,7 +1940,7 @@ module Sinatra
             <img src='#{uri "/__sinatra__/404.png"}'>
             <div id="c">
               Try this:
-              <pre>#{code}</pre>
+              <pre>#{Rack::Utils.escape_html(code)}</pre>
             </div>
           </body>
           </html>
@@ -2019,8 +2018,7 @@ module Sinatra
     end
   end
 
-  # Create a new Sinatra application. The block is evaluated in the new app's
-  # class scope.
+  # Create a new Sinatra application; the block is evaluated in the class scope.
   def self.new(base = Base, &block)
     base = Class.new(base)
     base.class_eval(&block) if block_given?
