@@ -1,6 +1,6 @@
 require File.expand_path('../helper', __FILE__)
 
-class DelegatorTest < Test::Unit::TestCase
+class DelegatorTest < Minitest::Test
   class Mirror
     attr_reader :last_call
     def method_missing(*a, &b)
@@ -60,12 +60,10 @@ class DelegatorTest < Test::Unit::TestCase
     assert_equal Sinatra::Application, Sinatra::Delegator.target
   end
 
-  %w[get put post delete options patch].each do |verb|
+  %w[get put post delete options patch link unlink].each do |verb|
     it "delegates #{verb} correctly" do
       delegation_app do
-        send verb, '/hello' do
-          'Hello World'
-        end
+        send(verb, '/hello') { 'Hello World' }
       end
 
       request = Rack::MockRequest.new(@app)
@@ -102,7 +100,7 @@ class DelegatorTest < Test::Unit::TestCase
     assert_equal ["helpers", mixin.to_s], app.last_call
   end
 
-  it "registers helpers with the delegation target" do
+  it "registers middleware with the delegation target" do
     app, mixin = mirror, Module.new
     Sinatra.use mixin
     assert_equal ["use", mixin.to_s], app.last_call
